package com.rshy.project.hy.aop;

import com.rshy.project.hy.annotation.NoRepeatSubmit;
import com.rshy.project.hy.baseRe.Ret;
import com.rshy.project.hy.cache.CacheUtil;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;

@Aspect
@Component
@Slf4j
public class NoRepeatSubmitAop {

    private static final String CACHE_NAME = "";

    @Around("execution(* com.rshy..*Controller.*(..)) && @annotation(nrs)")
    public Object arround(ProceedingJoinPoint pjp, NoRepeatSubmit nrs) throws Throwable{
        try {
            ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
            String sessionId = RequestContextHolder.getRequestAttributes().getSessionId();
            HttpServletRequest request = attributes.getRequest();
            String key = sessionId + "-" + request.getServletPath();
            // 如果缓存中有这个url视为重复提交
            if (CacheUtil.get(CACHE_NAME, key) == null) {
                Object o = pjp.proceed();
                CacheUtil.put(CACHE_NAME, key,0,2);
                return o;
            } else {
                return Ret.error(10003,"请勿频繁提交");
            }
        } catch (Throwable e) {
            e.printStackTrace();
            log.error("验证重复提交时出现未知异常!",e);
            throw e;
        }

    }


}
